I am developing a C# MVC application. I am using a View and Display template to manage the User Interface. The Users are able to edit the data presented on multiple pages. I am having an issue posting the Datatable data from all pages to the Controller. The List object in the Model returned to the Controller contains the correct number of rows, but the column values of all the rows except the rows on the last edited page are null. How do I post all of the data to the Controller?

**Code from my View:**
@model TreatyMilestonesViewModel
@{
    ViewData["Title"] = "Treaty Milestones";
}
<link rel="stylesheet" type="text/css" href="~/lib/datatables/media/css/jquery.dataTables.min.css">
<script type="text/javascript" language="javascript" src="~/lib/datatables/media/js/jquery.dataTables.min.js"></script>
<script type="text/javascript" language="javascript" src="~/lib/datatables.net-plugins/sorting/custom-data-source/dom-checkbox.js"></script>
<script type="text/javascript" language="javascript" src="~/lib/datatables.net-plugins/sorting/num-html.js"></script>
<script type="text/javascript" language="javascript" src="~/lib/datatables.net-plugins/sorting/signed-num.js"></script>

<script type="text/javascript" charset="utf-8">
    $(document).ready(function () {
        // DataTables initialisation
        if (@Model.TreatyMilestonesList.Count() > 1) {
            $('#TreatyMilestones').DataTable({
                "columns": [
                    { "orderDataType": "dom-checkbox" },
                    null,
                    null,
                    null,
                    { "orderDataType": "dom-checkbox" },
                    null
                ],
                "columnDefs": [
                    { "orderable": false, "targets": 5 }
                ],
                "order": [[0, 'desc']]
            });
        };
        $('#TreatyMilestones').DataTable().on('click', '.rowBinder', function () {
            //  This seems like the answer, but I do not understand how to actually implement it
            // https://stackoverflow.com/questions/16119693/jquery-data-table-not-working- 
               from-second-page
        });
    });

    function enableFields(assignedMilestone) {
        var rownum = assignedMilestone.name.match(/(\d+)/g);
        var sla = '#TreatyMilestonesList_' + rownum + '__TreatyMilestoneSLA';
        var inactive = '#TreatyMilestonesList_' + rownum + '__Inactive'
        $(sla).prop('disabled', !assignedMilestone.checked);
        $(inactive).prop('disabled', !assignedMilestone.checked);
    };
</script>

@using (@Html.BeginForm())
{
    <h2> @Model.SelectedTreatyName - Treaty Milestones </h2>
    @Html.HiddenFor(modelItem => modelItem.SelectedTreatyId)
    <table class="table table-striped table-hover row-border order-column oBinder" 
         id="TreatyMilestones">
        <thead>
            <tr>
                <th>@Html.Label("Assigned Milestone")</th>
                <th>@Html.Label("Milestone Description")</th>
                <th>@Html.Label("Milestone SLA")</th>
                <th>@Html.Label("Processing Period")</th>
                <th>@Html.Label("Inactive")</th>
                <th>@Html.HiddenFor(modelItem => modelItem.SelectedTreatyId) 
                        @Html.HiddenFor(modelItem => 
                       modelItem.SelectedTreatyName)</th>
            </tr>
        </thead>
        <tbody>
            @Html.DisplayFor(model => model.TreatyMilestonesList)
        </tbody>
    </table>

    <div class="row">
        <div class="col-lg-2">
            <input type="submit" name="response" value="Save" 
                   formaction=@Url.Action("SaveMilestones") formmethod="post"
                   class="btn btn-link" />
        </div>
        <div class="col-lg-10">
            <a asp-action="Index" class="btn btn-link">Back to Treaty Selection</a>
        </div>
    </div>
}

**Code form my Display Template:
```@model MilestoneTracking.Models**.TreatyMilestonesList

<tr class="rowBinder">
    <td>
        @if (this.ViewContext.HttpContext.Request.Cookies["mtaUserRole"] != "IsAppUser")
        {
            @Html.CheckBoxFor(modelItem => modelItem.AssignedMilestone, new { onchange="enableFields(this)"})
        }
        else //This is an "AppUser", do not allow editing
        {
            @Html.CheckBoxFor(modelItem => modelItem.AssignedMilestone, new { disabled = "disabled" })
        }
    </td>
    <td>@Html.DisplayFor(modelItem => modelItem.MilestoneDescription)</td>
    <td>
        @if (Model.AssignedMilestone)
        {
            @Html.TextBoxFor(modelItem => modelItem.TreatyMilestoneSLA, new { type = "number" })
        }
        else
        {
            @Html.TextBoxFor(modelItem => modelItem.TreatyMilestoneSLA, new { disabled = "disabled", type = "number" })
        }
        @Html.ValidationMessageFor(modelItem => modelItem.TreatyMilestoneSLA)
    </td>
    <td>
        @Html.DisplayFor(modelItem => modelItem.ProcessingPeriod)
    </td>
    <td>
        @if (Model.AssignedMilestone)
        {
            @Html.CheckBoxFor(modelItem => modelItem.Inactive)
        }
        else
        {
            @Html.CheckBoxFor(modelItem => modelItem.Inactive, new { disabled = "disabled" })
        }
    </td>
    <td>
        @*These were put here for two reasons; 
            1. They are within a <td> to eliminiate HTML warning 1503 "Unexpected start tag"
            2. They were initially moved within the first column to eliminate the warning, but having them there broke the checkbox 
                 sorting feature hence I moved them to their own cell.*@
        @Html.HiddenFor(modelItem => modelItem.TreatyMilestoneId)
        @Html.HiddenFor(modelItem => modelItem.TreatyId)
        @Html.HiddenFor(modelItem => modelItem.MilestoneId)
        @Html.HiddenFor(modelItem => modelItem.TreatyName)
    </td>
</tr>

**Code from Controller:**
```        [HttpPost]
        public ActionResult SaveMilestones(TreatyMilestonesViewModel _model)
        {
            // retrieve the as-is state of currently assigned Milestones
            List<TreatyMilestone> currentlyAssignedMilestones = GetCurrentlyAssignedMilestones(_model.SelectedTreatyId);
            // Let's create this now and we will assign the TreatyId and TreatyName to be passed back to the View after processing is completed
            TreatyMilestonesViewModel vm = new TreatyMilestonesViewModel()
            {
                //SelectedTreatyId = _model.TreatyMilestonesList[0].TreatyId,
                //SelectedTreatyName = _model.TreatyMilestonesList[0].TreatyName
                SelectedTreatyId = _model.SelectedTreatyId,
                SelectedTreatyName = _model.SelectedTreatyName
            };
            
            foreach (TreatyMilestonesList tmlrec in _model.TreatyMilestonesList)
            {
               ...
